==> django-frog-0.6.2.zip: django-frog-0.6.2/frog/plugin.py <==
"""
Copyright (c) 2012 Brett Dixon

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the 
Software, and to permit persons to whom the Software is furnished to do so, 
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""


class FrogPluginRegistry(type):
    plugins = {}
    def __init__(cls, name, bases, attrs):
        if name != 'FrogPlugin' and name not in FrogPluginRegistry.plugins.keys():
            FrogPluginRegistry.plugins[name] = cls

class FrogPlugin(object):
    __metaclass__ = FrogPluginRegistry

    def buttonHook(self):
        """ 
        Return a dict with label, callback, js, and css lists
        """
        return None

    def managerHook(self):
        """ 
        Return a dict with label, callback, js, and css lists
        """
        return None

==> django-frog-0.7.5.zip: django-frog-0.7.5/frog/plugin.py <==
"""
Copyright (c) 2012 Brett Dixon

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the 
Software, and to permit persons to whom the Software is furnished to do so, 
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""


class FrogPluginRegistry(type):
    plugins = {}
    def __init__(cls, name, bases, attrs):
        if name != 'FrogPlugin' and name not in FrogPluginRegistry.plugins.keys():
            FrogPluginRegistry.plugins[name] = cls

class FrogPlugin(object):
    __metaclass__ = FrogPluginRegistry

    def data(self):
        """ 
        Return a dict with label, callback, altclick, js, and css lists
        """
        return None
